import { utils, BigNumberish, BytesLike, BigNumber, BaseContract, Signer, PayableOverrides, ContractTransaction, CallOverrides, Overrides, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface IDropERC20Interface extends utils.Interface {
    contractName: string | "IDropERC20";
    functions: {
        "claim(address,uint256,bytes32[])": FunctionFragment;
        "contractType()": FunctionFragment;
        "contractURI()": FunctionFragment;
        "contractVersion()": FunctionFragment;
        "getPlatformFeeInfo()": FunctionFragment;
        "primarySaleRecipient()": FunctionFragment;
        "setClaimConditions((uint256,uint256,uint256,uint256,bytes32,uint256,address)[],bool)": FunctionFragment;
        "setContractURI(string)": FunctionFragment;
        "setPlatformFeeInfo(address,uint256)": FunctionFragment;
        "setPrimarySaleRecipient(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "claim", values: [string, BigNumberish, BytesLike[]]): string;
    encodeFunctionData(functionFragment: "contractType", values?: undefined): string;
    encodeFunctionData(functionFragment: "contractURI", values?: undefined): string;
    encodeFunctionData(functionFragment: "contractVersion", values?: undefined): string;
    encodeFunctionData(functionFragment: "getPlatformFeeInfo", values?: undefined): string;
    encodeFunctionData(functionFragment: "primarySaleRecipient", values?: undefined): string;
    encodeFunctionData(functionFragment: "setClaimConditions", values: [IDropERC20.ClaimConditionStruct[], boolean]): string;
    encodeFunctionData(functionFragment: "setContractURI", values: [string]): string;
    encodeFunctionData(functionFragment: "setPlatformFeeInfo", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setPrimarySaleRecipient", values: [string]): string;
    decodeFunctionResult(functionFragment: "claim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractType", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractVersion", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPlatformFeeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "primarySaleRecipient", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setClaimConditions", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setContractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPlatformFeeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPrimarySaleRecipient", data: BytesLike): Result;
    events: {
        "ClaimedTokens(uint256,address,address,uint256)": EventFragment;
        "EtherReceived(address,uint256)": EventFragment;
        "FundsWithdrawn(address,address,uint256,uint256)": EventFragment;
        "NewClaimConditions(tuple[])": EventFragment;
        "NewPrimarySaleRecipient(address)": EventFragment;
        "PlatformFeeUpdates(address,uint256)": EventFragment;
        "RoyaltyUpdated(address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ClaimedTokens"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "EtherReceived"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "FundsWithdrawn"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewClaimConditions"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewPrimarySaleRecipient"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PlatformFeeUpdates"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoyaltyUpdated"): EventFragment;
}
declare type ClaimedTokensEvent = TypedEvent<[
    BigNumber,
    string,
    string,
    BigNumber
], {
    claimConditionIndex: BigNumber;
    claimer: string;
    receiver: string;
    quantityClaimed: BigNumber;
}>;
declare type ClaimedTokensEventFilter = TypedEventFilter<ClaimedTokensEvent>;
declare type EtherReceivedEvent = TypedEvent<[
    string,
    BigNumber
], {
    sender: string;
    amount: BigNumber;
}>;
declare type EtherReceivedEventFilter = TypedEventFilter<EtherReceivedEvent>;
declare type FundsWithdrawnEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    BigNumber
], {
    paymentReceiver: string;
    feeRecipient: string;
    totalAmount: BigNumber;
    feeCollected: BigNumber;
}>;
declare type FundsWithdrawnEventFilter = TypedEventFilter<FundsWithdrawnEvent>;
declare type NewClaimConditionsEvent = TypedEvent<[
    IDropERC20.ClaimConditionStructOutput[]
], {
    claimConditions: IDropERC20.ClaimConditionStructOutput[];
}>;
declare type NewClaimConditionsEventFilter = TypedEventFilter<NewClaimConditionsEvent>;
declare type NewPrimarySaleRecipientEvent = TypedEvent<[
    string
], {
    recipient: string;
}>;
declare type NewPrimarySaleRecipientEventFilter = TypedEventFilter<NewPrimarySaleRecipientEvent>;
declare type PlatformFeeUpdatesEvent = TypedEvent<[
    string,
    BigNumber
], {
    platformFeeRecipient: string;
    platformFeeBps: BigNumber;
}>;
declare type PlatformFeeUpdatesEventFilter = TypedEventFilter<PlatformFeeUpdatesEvent>;
declare type RoyaltyUpdatedEvent = TypedEvent<[
    string,
    BigNumber
], {
    newRoyaltyRecipient: string;
    newRoyaltyBps: BigNumber;
}>;
declare type RoyaltyUpdatedEventFilter = TypedEventFilter<RoyaltyUpdatedEvent>;
declare namespace IDropERC20 {
    type ClaimConditionStruct = {
        startTimestamp: BigNumberish;
        maxClaimableSupply: BigNumberish;
        supplyClaimed: BigNumberish;
        waitTimeInSecondsBetweenClaims: BigNumberish;
        merkleRoot: BytesLike;
        pricePerToken: BigNumberish;
        currency: string;
    };
    type ClaimConditionStructOutput = [
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        string,
        BigNumber,
        string
    ] & {
        startTimestamp: BigNumber;
        maxClaimableSupply: BigNumber;
        supplyClaimed: BigNumber;
        waitTimeInSecondsBetweenClaims: BigNumber;
        merkleRoot: string;
        pricePerToken: BigNumber;
        currency: string;
    };
}
interface IDropERC20 extends BaseContract {
    contractName: string | "IDropERC20";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IDropERC20Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        claim(receiver: string, quantity: BigNumberish, proof: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        contractType(overrides?: CallOverrides): Promise<[string]>;
        contractURI(overrides?: CallOverrides): Promise<[string]>;
        contractVersion(overrides?: CallOverrides): Promise<[number]>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
            string,
            number
        ] & {
            platformFeeRecipient: string;
            platformFeeBps: number;
        }>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<[string]>;
        setClaimConditions(conditions: IDropERC20.ClaimConditionStruct[], resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    claim(receiver: string, quantity: BigNumberish, proof: BytesLike[], overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    contractType(overrides?: CallOverrides): Promise<string>;
    contractURI(overrides?: CallOverrides): Promise<string>;
    contractVersion(overrides?: CallOverrides): Promise<number>;
    getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
        string,
        number
    ] & {
        platformFeeRecipient: string;
        platformFeeBps: number;
    }>;
    primarySaleRecipient(overrides?: CallOverrides): Promise<string>;
    setClaimConditions(conditions: IDropERC20.ClaimConditionStruct[], resetRestriction: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setContractURI(_uri: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        claim(receiver: string, quantity: BigNumberish, proof: BytesLike[], overrides?: CallOverrides): Promise<void>;
        contractType(overrides?: CallOverrides): Promise<string>;
        contractURI(overrides?: CallOverrides): Promise<string>;
        contractVersion(overrides?: CallOverrides): Promise<number>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
            string,
            number
        ] & {
            platformFeeRecipient: string;
            platformFeeBps: number;
        }>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<string>;
        setClaimConditions(conditions: IDropERC20.ClaimConditionStruct[], resetRestriction: boolean, overrides?: CallOverrides): Promise<void>;
        setContractURI(_uri: string, overrides?: CallOverrides): Promise<void>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ClaimedTokens(uint256,address,address,uint256)"(claimConditionIndex?: BigNumberish | null, claimer?: string | null, receiver?: string | null, quantityClaimed?: null): ClaimedTokensEventFilter;
        ClaimedTokens(claimConditionIndex?: BigNumberish | null, claimer?: string | null, receiver?: string | null, quantityClaimed?: null): ClaimedTokensEventFilter;
        "EtherReceived(address,uint256)"(sender?: null, amount?: null): EtherReceivedEventFilter;
        EtherReceived(sender?: null, amount?: null): EtherReceivedEventFilter;
        "FundsWithdrawn(address,address,uint256,uint256)"(paymentReceiver?: string | null, feeRecipient?: null, totalAmount?: null, feeCollected?: null): FundsWithdrawnEventFilter;
        FundsWithdrawn(paymentReceiver?: string | null, feeRecipient?: null, totalAmount?: null, feeCollected?: null): FundsWithdrawnEventFilter;
        "NewClaimConditions(tuple[])"(claimConditions?: null): NewClaimConditionsEventFilter;
        NewClaimConditions(claimConditions?: null): NewClaimConditionsEventFilter;
        "NewPrimarySaleRecipient(address)"(recipient?: string | null): NewPrimarySaleRecipientEventFilter;
        NewPrimarySaleRecipient(recipient?: string | null): NewPrimarySaleRecipientEventFilter;
        "PlatformFeeUpdates(address,uint256)"(platformFeeRecipient?: null, platformFeeBps?: null): PlatformFeeUpdatesEventFilter;
        PlatformFeeUpdates(platformFeeRecipient?: null, platformFeeBps?: null): PlatformFeeUpdatesEventFilter;
        "RoyaltyUpdated(address,uint256)"(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
        RoyaltyUpdated(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
    };
    estimateGas: {
        claim(receiver: string, quantity: BigNumberish, proof: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        contractType(overrides?: CallOverrides): Promise<BigNumber>;
        contractURI(overrides?: CallOverrides): Promise<BigNumber>;
        contractVersion(overrides?: CallOverrides): Promise<BigNumber>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<BigNumber>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<BigNumber>;
        setClaimConditions(conditions: IDropERC20.ClaimConditionStruct[], resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        claim(receiver: string, quantity: BigNumberish, proof: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        contractType(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        contractURI(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        contractVersion(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setClaimConditions(conditions: IDropERC20.ClaimConditionStruct[], resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}

export { ClaimedTokensEvent, ClaimedTokensEventFilter, EtherReceivedEvent, EtherReceivedEventFilter, FundsWithdrawnEvent, FundsWithdrawnEventFilter, IDropERC20, IDropERC20Interface, NewClaimConditionsEvent, NewClaimConditionsEventFilter, NewPrimarySaleRecipientEvent, NewPrimarySaleRecipientEventFilter, PlatformFeeUpdatesEvent, PlatformFeeUpdatesEventFilter, RoyaltyUpdatedEvent, RoyaltyUpdatedEventFilter };
