import { utils, BytesLike, BigNumberish, BigNumber, BaseContract, Signer, CallOverrides, Overrides, ContractTransaction, PayableOverrides, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface TWPricingInterface extends utils.Interface {
    contractName: string | "TWPricing";
    functions: {
        "DEFAULT_ADMIN_ROLE()": FunctionFragment;
        "getRoleAdmin(bytes32)": FunctionFragment;
        "getRoleMember(bytes32,uint256)": FunctionFragment;
        "getRoleMemberCount(bytes32)": FunctionFragment;
        "grantRole(bytes32,address)": FunctionFragment;
        "hasRole(bytes32,address)": FunctionFragment;
        "isApproved(address,address)": FunctionFragment;
        "isCurrencyApproved(uint256,address)": FunctionFragment;
        "isTrustedForwarder(address)": FunctionFragment;
        "multicall(bytes[])": FunctionFragment;
        "priceToPayForCurrency(uint256,address)": FunctionFragment;
        "renounceRole(bytes32,address)": FunctionFragment;
        "revokeRole(bytes32,address)": FunctionFragment;
        "selectSubscription(address,uint128,uint128,uint256,address)": FunctionFragment;
        "setPricingTierInfo(uint256,uint256,address,uint256,bool)": FunctionFragment;
        "setTreasury(address)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "thirdwebTreasury()": FunctionFragment;
        "tierDuration(uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "DEFAULT_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRoleAdmin", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getRoleMember", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getRoleMemberCount", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "grantRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "hasRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "isApproved", values: [string, string]): string;
    encodeFunctionData(functionFragment: "isCurrencyApproved", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "isTrustedForwarder", values: [string]): string;
    encodeFunctionData(functionFragment: "multicall", values: [BytesLike[]]): string;
    encodeFunctionData(functionFragment: "priceToPayForCurrency", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "renounceRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "revokeRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "selectSubscription", values: [string, BigNumberish, BigNumberish, BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "setPricingTierInfo", values: [BigNumberish, BigNumberish, string, BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "setTreasury", values: [string]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "thirdwebTreasury", values?: undefined): string;
    encodeFunctionData(functionFragment: "tierDuration", values: [BigNumberish]): string;
    decodeFunctionResult(functionFragment: "DEFAULT_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMember", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMemberCount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "grantRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hasRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isCurrencyApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isTrustedForwarder", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "multicall", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "priceToPayForCurrency", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "revokeRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "selectSubscription", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPricingTierInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTreasury", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "thirdwebTreasury", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tierDuration", data: BytesLike): Result;
    events: {
        "NewTreasury(address,address)": EventFragment;
        "PricingTierInfo(uint256,address,bool,uint256,uint256)": EventFragment;
        "RoleAdminChanged(bytes32,bytes32,bytes32)": EventFragment;
        "RoleGranted(bytes32,address,address)": EventFragment;
        "RoleRevoked(bytes32,address,address)": EventFragment;
        "TierForUser(address,uint256,address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "NewTreasury"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PricingTierInfo"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleAdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleGranted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleRevoked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TierForUser"): EventFragment;
}
declare type NewTreasuryEvent = TypedEvent<[
    string,
    string
], {
    oldTreasury: string;
    newTreasury: string;
}>;
declare type NewTreasuryEventFilter = TypedEventFilter<NewTreasuryEvent>;
declare type PricingTierInfoEvent = TypedEvent<[
    BigNumber,
    string,
    boolean,
    BigNumber,
    BigNumber
], {
    tier: BigNumber;
    currency: string;
    isCurrencyApproved: boolean;
    _duration: BigNumber;
    priceForCurrency: BigNumber;
}>;
declare type PricingTierInfoEventFilter = TypedEventFilter<PricingTierInfoEvent>;
declare type RoleAdminChangedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    previousAdminRole: string;
    newAdminRole: string;
}>;
declare type RoleAdminChangedEventFilter = TypedEventFilter<RoleAdminChangedEvent>;
declare type RoleGrantedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
declare type RoleGrantedEventFilter = TypedEventFilter<RoleGrantedEvent>;
declare type RoleRevokedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
declare type RoleRevokedEventFilter = TypedEventFilter<RoleRevokedEvent>;
declare type TierForUserEvent = TypedEvent<[
    string,
    BigNumber,
    string,
    BigNumber,
    BigNumber
], {
    user: string;
    tier: BigNumber;
    currencyForPayment: string;
    pricePaid: BigNumber;
    expirationTimestamp: BigNumber;
}>;
declare type TierForUserEventFilter = TypedEventFilter<TierForUserEvent>;
interface TWPricing extends BaseContract {
    contractName: string | "TWPricing";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TWPricingInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<[BigNumber]>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<[boolean]>;
        isApproved(arg0: string, arg1: string, overrides?: CallOverrides): Promise<[boolean]>;
        isCurrencyApproved(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<[boolean]>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<[boolean]>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        priceToPayForCurrency(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        selectSubscription(_for: string, _tier: BigNumberish, _cycles: BigNumberish, _priceToPay: BigNumberish, _currencyToUse: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPricingTierInfo(_tier: BigNumberish, _duration: BigNumberish, _currencyToApprove: string, _priceForCurrency: BigNumberish, _toApproveCurrency: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setTreasury(_newTreasury: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
        thirdwebTreasury(overrides?: CallOverrides): Promise<[string]>;
        tierDuration(_tier: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
    getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    grantRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
    isApproved(arg0: string, arg1: string, overrides?: CallOverrides): Promise<boolean>;
    isCurrencyApproved(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<boolean>;
    isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
    multicall(data: BytesLike[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    priceToPayForCurrency(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<BigNumber>;
    renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    selectSubscription(_for: string, _tier: BigNumberish, _cycles: BigNumberish, _priceToPay: BigNumberish, _currencyToUse: string, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPricingTierInfo(_tier: BigNumberish, _duration: BigNumberish, _currencyToApprove: string, _priceForCurrency: BigNumberish, _toApproveCurrency: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setTreasury(_newTreasury: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    thirdwebTreasury(overrides?: CallOverrides): Promise<string>;
    tierDuration(_tier: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
        isApproved(arg0: string, arg1: string, overrides?: CallOverrides): Promise<boolean>;
        isCurrencyApproved(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<boolean>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
        multicall(data: BytesLike[], overrides?: CallOverrides): Promise<string[]>;
        priceToPayForCurrency(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        revokeRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        selectSubscription(_for: string, _tier: BigNumberish, _cycles: BigNumberish, _priceToPay: BigNumberish, _currencyToUse: string, overrides?: CallOverrides): Promise<void>;
        setPricingTierInfo(_tier: BigNumberish, _duration: BigNumberish, _currencyToApprove: string, _priceForCurrency: BigNumberish, _toApproveCurrency: boolean, overrides?: CallOverrides): Promise<void>;
        setTreasury(_newTreasury: string, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
        thirdwebTreasury(overrides?: CallOverrides): Promise<string>;
        tierDuration(_tier: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {
        "NewTreasury(address,address)"(oldTreasury?: null, newTreasury?: null): NewTreasuryEventFilter;
        NewTreasury(oldTreasury?: null, newTreasury?: null): NewTreasuryEventFilter;
        "PricingTierInfo(uint256,address,bool,uint256,uint256)"(tier?: BigNumberish | null, currency?: string | null, isCurrencyApproved?: null, _duration?: null, priceForCurrency?: null): PricingTierInfoEventFilter;
        PricingTierInfo(tier?: BigNumberish | null, currency?: string | null, isCurrencyApproved?: null, _duration?: null, priceForCurrency?: null): PricingTierInfoEventFilter;
        "RoleAdminChanged(bytes32,bytes32,bytes32)"(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        RoleAdminChanged(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        "RoleGranted(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        RoleGranted(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        "RoleRevoked(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        RoleRevoked(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        "TierForUser(address,uint256,address,uint256,uint256)"(user?: string | null, tier?: BigNumberish | null, currencyForPayment?: null, pricePaid?: null, expirationTimestamp?: null): TierForUserEventFilter;
        TierForUser(user?: string | null, tier?: BigNumberish | null, currencyForPayment?: null, pricePaid?: null, expirationTimestamp?: null): TierForUserEventFilter;
    };
    estimateGas: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<BigNumber>;
        isApproved(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        isCurrencyApproved(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<BigNumber>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<BigNumber>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        priceToPayForCurrency(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        selectSubscription(_for: string, _tier: BigNumberish, _cycles: BigNumberish, _priceToPay: BigNumberish, _currencyToUse: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPricingTierInfo(_tier: BigNumberish, _duration: BigNumberish, _currencyToApprove: string, _priceForCurrency: BigNumberish, _toApproveCurrency: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setTreasury(_newTreasury: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        thirdwebTreasury(overrides?: CallOverrides): Promise<BigNumber>;
        tierDuration(_tier: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isApproved(arg0: string, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isCurrencyApproved(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        priceToPayForCurrency(_tier: BigNumberish, _currency: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        selectSubscription(_for: string, _tier: BigNumberish, _cycles: BigNumberish, _priceToPay: BigNumberish, _currencyToUse: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPricingTierInfo(_tier: BigNumberish, _duration: BigNumberish, _currencyToApprove: string, _priceForCurrency: BigNumberish, _toApproveCurrency: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setTreasury(_newTreasury: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        thirdwebTreasury(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tierDuration(_tier: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}

export { NewTreasuryEvent, NewTreasuryEventFilter, PricingTierInfoEvent, PricingTierInfoEventFilter, RoleAdminChangedEvent, RoleAdminChangedEventFilter, RoleGrantedEvent, RoleGrantedEventFilter, RoleRevokedEvent, RoleRevokedEventFilter, TWPricing, TWPricingInterface, TierForUserEvent, TierForUserEventFilter };
